import{r as e,t}from"./jsx-runtime-DAs1UGHr.js";import"./react-DxF41JXl.js";import"./free-solid-svg-icons-DaMIgByo.js";import"./use-api-Bu5WaDJh.js";import"./use-user-BydImGZB.js";import"./user-service-BcOsc0XC.js";import"./toast-context-val-CcPDsXTx.js";import"./page-container-DV9_twon.js";import"./entity-service-BKXKzuKW.js";import"./use-all-experiments-DCmrduIw.js";import"./search-input-Dyzd98vj.js";import"./icon-button-B4AblHF3.js";import"./use-toast-YQGdTBXl.js";import"./input-C6MMvIYu.js";import"./grant-permission-modal-C8d-GgKD.js";import{t as n}from"./shared-permissions-page-B1ZDFxx6.js";import"./use-user-prompt-permissions-BLHIG8gs.js";import"./use-all-models-DCa_9Lqg.js";import"./use-all-prompts-D1TslN8B.js";var r=e(t(),1);function i({type:e}){return(0,r.jsx)(n,{type:e,baseRoute:`/groups`,entityKind:`group`})}export{i as default};