import{t as e}from"./use-api-Bu5WaDJh.js";import{i as t}from"./user-service-BcOsc0XC.js";function n(){let{data:n,isLoading:r,error:i,refetch:a}=e(t);return{allUsers:n,isLoading:r,error:i,refresh:a}}export{n as t};