import{t as e}from"./use-api-Bu5WaDJh.js";import{r as t}from"./entity-service-BKXKzuKW.js";function n(){let{data:n,isLoading:r,error:i,refetch:a}=e(t);return{allModels:n,isLoading:r,error:i,refresh:a}}export{n as t};