import{r as e,t}from"./jsx-runtime-DAs1UGHr.js";import{t as n}from"./react-DxF41JXl.js";import{o as r}from"./chunk-EPOLDU6W-CNaCjKeI.js";import{E as i,d as a,k as o}from"./free-solid-svg-icons-DaMIgByo.js";n();var s=e(t(),1);function c({entityId:e,route:t,buttonText:n}){let c=r(),l=`${o().basePath}/${t}/${e}`;return(0,s.jsx)(i,{onClick:e=>{e.stopPropagation(),c(l)},icon:a,className:`gap-1`,children:n})}export{c as t};